@@ -393,10 +393,6 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "search_bar_type"
 	},
-	{ NAUTILUS_PREFERENCES_WINDOW_ALWAYS_NEW,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (FALSE)
-	},
 	{ NAUTILUS_PREFERENCES_ICON_VIEW_CAPTIONS,
 	  PREFERENCE_STRING_LIST,
 	  "size,date_modified,type",
@@ -412,10 +408,6 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (148)
 	},
-	{ NAUTILUS_PREFERENCES_START_WITH_TOOLBAR,
-	  PREFERENCE_BOOLEAN,
-	  GINT_TO_POINTER (TRUE)
-	},
 	{ NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR,
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
