@@ -27,10 +27,11 @@
 #ifndef NAUTILUS_APPLICATION_H
 #define NAUTILUS_APPLICATION_H
 
+#include <gdk/gdk.h>
 #include <bonobo/bonobo-generic-factory.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 
-#define NAUTILUS_DESKTOP_ICON_VIEW_IID	"OAFIID:nautilus_file_manager_desktop_icon_view:8d8121b1-0f1e-400b-bf0d-5b0f4555f5e1"
+#define NAUTILUS_DESKTOP_ICON_VIEW_IID	"OAFIID:Nautilus_File_Manager_Desktop_Icon_View"
 
 #define NAUTILUS_TYPE_APPLICATION	     (nautilus_application_get_type ())
 #define NAUTILUS_APPLICATION(obj)	     (GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_APPLICATION, NautilusApplication))
@@ -43,6 +44,11 @@
 typedef struct NautilusWindow NautilusWindow;
 #endif
 
+#ifndef NAUTILUS_SPATIAL_WINDOW_DEFINED
+#define NAUTILUS_SPATIAL_WINDOW_DEFINED
+typedef struct _NautilusSpatialWindow NautilusSpatialWindow;
+#endif
+
 typedef struct {
 	BonoboGenericFactory parent;
 	NautilusUndoManager *undo_manager;
@@ -62,9 +68,16 @@ void                 nautilus_application_startup           (NautilusApplication
 							     gboolean             do_first_time_druid_check,
 							     const char          *default_geometry,
 							     const char          *urls[]);
-GList *              nautilus_application_get_window_list   (void);
-NautilusWindow *     nautilus_application_create_window     (NautilusApplication *application);
-void                 nautilus_application_close_all_windows (void);
+GList *              nautilus_application_get_window_list           (void);
+GList *              nautilus_application_get_spatial_window_list    (void);
+
+NautilusWindow *     nautilus_application_present_spatial_window     (NautilusApplication *application,
+								      const char          *location,
+								      GdkScreen           *screen);
+NautilusWindow *     nautilus_application_create_navigation_window     (NautilusApplication *application,
+									GdkScreen           *screen);
+void                 nautilus_application_close_all_navigation_windows (void);
+void                 nautilus_application_close_with_parent_windows (NautilusSpatialWindow *window);
 void                 nautilus_application_open_desktop      (NautilusApplication *application);
 void                 nautilus_application_close_desktop     (void);
 
